# coding: utf-8

"""
    STEP REST API V2

    <h1>About</h1><p>The STEP REST API V2 provides read and write access to a set of core STEP objects using the HTTP operations GET, PUT, POST, PATCH and DELETE.</p><h1>Resource Representation</h1><p>With the exception of a few resource operations for retrieving and uploading binary data, all request and response bodies are JSON, compliant with the schema documented here.</p><h1>Context and Workspace</h1><p>All requests are handled in a specific STEP context and workspace and both can be specified via query parameters available for all resource operations. A context must always be specified while requests per default will be handled in the &quot;Main&quot; workspace.</p><h1>Polymorphism</h1><p>In STEP, attributes, reference types and data container types can all be either single- or multivalued. The STEP REST API V2 uses polymorphism to address this complexity with resources that include values, references and data containers specified to produce and consume a common &quot;abstract&quot; supertype that always will be one of either the single- or multivalued subtype.<br/>As an example, the GET /entities/{id}/values/{attributeId} resource operation is specified to return a &quot;Value&quot; but as evident from the model, the &quot;Value&quot; will always be &quot;oneOf&quot; either &quot;SingleValue&quot;, that has a &quot;value&quot; property for which the value is an object, or &quot;MultiValue&quot;, that has a &quot;values&quot; property for which the value is an array.<br/>Clients are advised to use the presence or absence of the plural array property (&quot;values&quot;, &quot;references&quot; and &quot;dataContainers&quot;) to determine the concrete type.</p><h1>Authentication</h1><p>The REST API is protected by HTTP Basic Authentication or if OAuth2-based authentication is enabled (SaaS customers only), by Bearer Authentication. With Basic Authentication, user name and password are supplied with each request and it is therefore highly recommended to only use the API in conjunction with HTTPS. For more information about OAuth2-based authentication for SaaS customers, please see the STEP Authentication Guide.</p><h1>Versioning</h1><p>The STEP REST API V2 is versioned using semantic versioning. Stibo Systems reserve the right to make non-breaking, minor / patch changes in any release without warning and clients must be coded / configured to be 'tolerant' and capable of handling such changes.</p><p>Examples of breaking, major changes:</p><ul><li>Renaming of a property</li><li>Removal of a property</li><li>Property type change</li><li>Addition of new property required for write operations</li><li>Marking existing property as required for write operations</li><li>Removal of resource or resource operation</li><li>Materially different behavior for existing resource operation</li></ul><p>Examples of non-breaking, minor / patch changes:</p><ul><li>Addition of new properties in request responses</li><li>Addition of new query parameter not required for write operations</li><li>Addition of new resource or resource operation</li><li>Bug fixes that do not change the schema or resource operations as described here</li><li>Inclusion of a response body for resource operations specified to return a 200 response with no body</li><li>Change of response &quot;Model&quot; / &quot;schema&quot; to type extending the previously specified type</li><li>Renaming a &quot;Model&quot; / &quot;schema&quot; type</li></ul><p>In addition, error message texts may change without warning within the same version. Client program logic should not depend upon the message content.</p><h1>Error Handling</h1><p>The STEP REST API V2 responds with standard HTTP status codes, with 2** responses indicating a success, 4** responses indicating a client error and 5** indicating a server error. Notice that this specification does not specify common error responses like 500 (internal server error) or 401 (unauthorized) for the individual resource operations. Clients should however be capable of handling such responses.</p><p>Error responses have a JSON response body (see Error schema below) containing HTTP status code information in addition to a message providing details about the error. As mentioned above, client program logic should not depend upon the message content.</p><p>The specific status codes used in the API are:</p><ul><li>200 (OK): Success, response may or may not have a body</li><li>201 (Created): Entity successfully created, response may or may not have a body</li><li>400 (Bad request): The server cannot or will not process the request due to an apparent client error</li><li>401 (Unauthorized): Returned only in relation to failed authentication</li><li>404 (Not Found): Returned only in relation to objects specified via path parameters (variable parts of the URL). If STEP objects referenced in request bodies or via query parameters cannot be found, the response will be 400.</li><li>429 (Too Many Requests): Clients are per default limited to 100 requests per second. Returned if the rate limit is exceeded.</li><li>500 (Internal Server Error): Unexpected error (could potentially cover an issue that rightfully should be a 400)</li></ul>

    The version of the OpenAPI document: 1.3.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "step-rest-client"
VERSION = "1.0.0"
PYTHON_REQUIRES = ">= 3.8"
REQUIRES = [
    "urllib3 >= 1.25.3, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="STEP REST API V2",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "STEP REST API V2"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description="""\
    &lt;h1&gt;About&lt;/h1&gt;&lt;p&gt;The STEP REST API V2 provides read and write access to a set of core STEP objects using the HTTP operations GET, PUT, POST, PATCH and DELETE.&lt;/p&gt;&lt;h1&gt;Resource Representation&lt;/h1&gt;&lt;p&gt;With the exception of a few resource operations for retrieving and uploading binary data, all request and response bodies are JSON, compliant with the schema documented here.&lt;/p&gt;&lt;h1&gt;Context and Workspace&lt;/h1&gt;&lt;p&gt;All requests are handled in a specific STEP context and workspace and both can be specified via query parameters available for all resource operations. A context must always be specified while requests per default will be handled in the &amp;quot;Main&amp;quot; workspace.&lt;/p&gt;&lt;h1&gt;Polymorphism&lt;/h1&gt;&lt;p&gt;In STEP, attributes, reference types and data container types can all be either single- or multivalued. The STEP REST API V2 uses polymorphism to address this complexity with resources that include values, references and data containers specified to produce and consume a common &amp;quot;abstract&amp;quot; supertype that always will be one of either the single- or multivalued subtype.&lt;br/&gt;As an example, the GET /entities/{id}/values/{attributeId} resource operation is specified to return a &amp;quot;Value&amp;quot; but as evident from the model, the &amp;quot;Value&amp;quot; will always be &amp;quot;oneOf&amp;quot; either &amp;quot;SingleValue&amp;quot;, that has a &amp;quot;value&amp;quot; property for which the value is an object, or &amp;quot;MultiValue&amp;quot;, that has a &amp;quot;values&amp;quot; property for which the value is an array.&lt;br/&gt;Clients are advised to use the presence or absence of the plural array property (&amp;quot;values&amp;quot;, &amp;quot;references&amp;quot; and &amp;quot;dataContainers&amp;quot;) to determine the concrete type.&lt;/p&gt;&lt;h1&gt;Authentication&lt;/h1&gt;&lt;p&gt;The REST API is protected by HTTP Basic Authentication or if OAuth2-based authentication is enabled (SaaS customers only), by Bearer Authentication. With Basic Authentication, user name and password are supplied with each request and it is therefore highly recommended to only use the API in conjunction with HTTPS. For more information about OAuth2-based authentication for SaaS customers, please see the STEP Authentication Guide.&lt;/p&gt;&lt;h1&gt;Versioning&lt;/h1&gt;&lt;p&gt;The STEP REST API V2 is versioned using semantic versioning. Stibo Systems reserve the right to make non-breaking, minor / patch changes in any release without warning and clients must be coded / configured to be &#39;tolerant&#39; and capable of handling such changes.&lt;/p&gt;&lt;p&gt;Examples of breaking, major changes:&lt;/p&gt;&lt;ul&gt;&lt;li&gt;Renaming of a property&lt;/li&gt;&lt;li&gt;Removal of a property&lt;/li&gt;&lt;li&gt;Property type change&lt;/li&gt;&lt;li&gt;Addition of new property required for write operations&lt;/li&gt;&lt;li&gt;Marking existing property as required for write operations&lt;/li&gt;&lt;li&gt;Removal of resource or resource operation&lt;/li&gt;&lt;li&gt;Materially different behavior for existing resource operation&lt;/li&gt;&lt;/ul&gt;&lt;p&gt;Examples of non-breaking, minor / patch changes:&lt;/p&gt;&lt;ul&gt;&lt;li&gt;Addition of new properties in request responses&lt;/li&gt;&lt;li&gt;Addition of new query parameter not required for write operations&lt;/li&gt;&lt;li&gt;Addition of new resource or resource operation&lt;/li&gt;&lt;li&gt;Bug fixes that do not change the schema or resource operations as described here&lt;/li&gt;&lt;li&gt;Inclusion of a response body for resource operations specified to return a 200 response with no body&lt;/li&gt;&lt;li&gt;Change of response &amp;quot;Model&amp;quot; / &amp;quot;schema&amp;quot; to type extending the previously specified type&lt;/li&gt;&lt;li&gt;Renaming a &amp;quot;Model&amp;quot; / &amp;quot;schema&amp;quot; type&lt;/li&gt;&lt;/ul&gt;&lt;p&gt;In addition, error message texts may change without warning within the same version. Client program logic should not depend upon the message content.&lt;/p&gt;&lt;h1&gt;Error Handling&lt;/h1&gt;&lt;p&gt;The STEP REST API V2 responds with standard HTTP status codes, with 2** responses indicating a success, 4** responses indicating a client error and 5** indicating a server error. Notice that this specification does not specify common error responses like 500 (internal server error) or 401 (unauthorized) for the individual resource operations. Clients should however be capable of handling such responses.&lt;/p&gt;&lt;p&gt;Error responses have a JSON response body (see Error schema below) containing HTTP status code information in addition to a message providing details about the error. As mentioned above, client program logic should not depend upon the message content.&lt;/p&gt;&lt;p&gt;The specific status codes used in the API are:&lt;/p&gt;&lt;ul&gt;&lt;li&gt;200 (OK): Success, response may or may not have a body&lt;/li&gt;&lt;li&gt;201 (Created): Entity successfully created, response may or may not have a body&lt;/li&gt;&lt;li&gt;400 (Bad request): The server cannot or will not process the request due to an apparent client error&lt;/li&gt;&lt;li&gt;401 (Unauthorized): Returned only in relation to failed authentication&lt;/li&gt;&lt;li&gt;404 (Not Found): Returned only in relation to objects specified via path parameters (variable parts of the URL). If STEP objects referenced in request bodies or via query parameters cannot be found, the response will be 400.&lt;/li&gt;&lt;li&gt;429 (Too Many Requests): Clients are per default limited to 100 requests per second. Returned if the rate limit is exceeded.&lt;/li&gt;&lt;li&gt;500 (Internal Server Error): Unexpected error (could potentially cover an issue that rightfully should be a 400)&lt;/li&gt;&lt;/ul&gt;
    """,  # noqa: E501
    package_data={"step_rest_client": ["py.typed"]},
)